==> test-services-utils-9.6.0-sources.jar: com/xebialabs/xlplatform/test/tasksystem/InMemoryPendingTaskRepository.scala <==
package com.xebialabs.xlplatform.test.tasksystem

import java.util

import com.xebialabs.deployit.engine.api.execution.TaskWithBlock
import com.xebialabs.deployit.engine.tasker.repository.{PendingTask, PendingTaskRepository}
import com.xebialabs.deployit.engine.tasker.{TaskId, TaskSpecification}
import org.joda.time.DateTime

import scala.collection.JavaConverters._
import scala.collection.mutable
import scala.util.Try

class InMemoryPendingTaskRepository extends PendingTaskRepository {

  private val _tasks = mutable.Map[TaskId, (TaskSpecification, Option[DateTime])]()

  override def delete(taskId: TaskId): Unit = _tasks.remove(taskId)

  override def tasks(loadFullSpec: Boolean): util.List[TaskWithBlock] = {
    _tasks.map { case (id, (spec, scheduledDate)) => pendingTask(id)(spec, scheduledDate).asInstanceOf[TaskWithBlock] }.toList.asJava
  }

  override def task(taskId: TaskId, loadFullSpec: Boolean = false): Option[PendingTask] = {
    val task: Option[PendingTask] = _tasks.get(taskId).map { case (spec, scheduledDate) => pendingTask(taskId)(spec, scheduledDate) }
    task
  }

  override def store(spec: TaskSpecification, workerAddress: Option[String]): TaskId = {
    val taskId = spec.getId
    _tasks.put(taskId, (spec, None))
    taskId
  }

  override def changeOwner(taskId: TaskId, newOwner: String): Unit = ???

  override def update(taskId: TaskId, spec: TaskSpecification): Unit = {
    task(taskId, loadFullSpec = true).foreach { t => _tasks.put(taskId, (t.spec.get, Some(t.scheduledDate))) }
  }

  override def schedule(taskId: TaskId, date: DateTime): Unit = {
    task(taskId, loadFullSpec = true).foreach { t => _tasks.put(taskId, (t.spec.get, Some(date))) }
  }

  private def pendingTask(id: TaskId)(spec: TaskSpecification, scheduledDate: Option[DateTime]): PendingTask = {
    new PendingTask(id, spec.getDescription, spec.getOwner.getName, spec.getMetadata, null, Some(spec), None)
  }

  override def scheduledTasks(): util.List[TaskWithBlock] = _tasks.foldLeft[List[TaskWithBlock]](List.empty){
    case (acc: util.List[TaskWithBlock], (taskId: TaskId, (spec: TaskSpecification, date: Option[DateTime]))) =>
    if (date.isDefined) {
      val result = pendingTask(taskId)(spec, date) :: acc
      result
    } else {
      acc
    }
  }.asJava

  override def prepareToEnqueue(taskId: TaskId): Try[TaskWithBlock] = Try(task(taskId).get)
}

==> test-services-utils-9.7.8-sources.jar: com/xebialabs/xlplatform/test/tasksystem/InMemoryPendingTaskRepository.scala <==
package com.xebialabs.xlplatform.test.tasksystem

import java.util

import com.xebialabs.deployit.engine.api.execution.TaskWithBlock
import com.xebialabs.deployit.engine.tasker.repository.{PendingTask, PendingTaskRepository}
import com.xebialabs.deployit.engine.tasker.{TaskId, TaskSpecification}
import grizzled.slf4j.Logging
import org.joda.time.DateTime

import scala.collection.JavaConverters._
import scala.collection.mutable
import scala.util.Try

class InMemoryPendingTaskRepository extends PendingTaskRepository with Logging {

  private val _tasks = mutable.Map[TaskId, (TaskSpecification, Option[DateTime])]()

  override def delete(taskId: TaskId): Unit = _tasks.remove(taskId)

  override def tasks(loadFullSpec: Boolean): util.List[TaskWithBlock] = {
    _tasks.map { case (id, (spec, scheduledDate)) => pendingTask(id)(spec, scheduledDate).asInstanceOf[TaskWithBlock] }.toList.asJava
  }

  override def task(taskId: TaskId, loadFullSpec: Boolean = false): Option[PendingTask] = {
    val task: Option[PendingTask] = _tasks.get(taskId).map { case (spec, scheduledDate) => pendingTask(taskId)(spec, scheduledDate) }
    task
  }

  override def store(spec: TaskSpecification, workerAddress: Option[String]): TaskId = {
    val taskId = spec.getId
    _tasks.put(taskId, (spec, None))
    taskId
  }

  override def changeOwner(taskId: TaskId, newOwner: String): Unit = ???

  override def update(taskId: TaskId, spec: TaskSpecification): Unit = {
    task(taskId, loadFullSpec = true).foreach { t => _tasks.put(taskId, (t.spec.get, Some(t.scheduledDate))) }
  }

  override def markAsSentToQueue(taskId: String): Unit = {
    logger.warn(s"markAsSentToQueue for taskId $taskId : This method is not implemented!")
  }

  override def schedule(taskId: TaskId, date: DateTime): Unit = {
    task(taskId, loadFullSpec = true).foreach { t => _tasks.put(taskId, (t.spec.get, Some(date))) }
  }

  private def pendingTask(id: TaskId)(spec: TaskSpecification, scheduledDate: Option[DateTime]): PendingTask = {
    new PendingTask(id, spec.getDescription, spec.getOwner.getName, spec.getMetadata, null, Some(spec), None)
  }

  override def scheduledTasks(): util.List[TaskWithBlock] = _tasks.foldLeft[List[TaskWithBlock]](List.empty) {
    case (acc: util.List[TaskWithBlock], (taskId: TaskId, (spec: TaskSpecification, date: Option[DateTime]))) =>
    if (date.isDefined) {
      val result = pendingTask(taskId)(spec, date) :: acc
      result
    } else {
      acc
    }
  }.asJava

  override def prepareToEnqueue(taskId: TaskId): Try[TaskWithBlock] = Try(task(taskId).get)
}
